"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const args_1 = tslib_1.__importDefault(require("args"));
const fs_1 = require("fs");
const path_1 = require("path");
const util_1 = require("util");
const constants_1 = require("./utils/constants");
const accessAsync = util_1.promisify(fs_1.access);
args_1.default
    .option(["", "blobHost"], "Optional. Customize listening address for blob", constants_1.DEFAULT_BLOB_SERVER_HOST_NAME)
    .option(["", "blobPort"], "Optional. Customize listening port for blob", constants_1.DEFAULT_BLOB_LISTENING_PORT)
    .option("location", "Optional. Use an existing folder as workspace path, default is current working directory", process.cwd())
    .option("silent", "Optional. Disable access log displayed in console")
    .option("debug", "Optional. Enable debug log by providing a valid local file path as log destination");
args_1.default.config.name = "azurite-queue";
class BlobEnvironment {
    constructor() {
        this.flags = args_1.default.parse(process.argv);
    }
    blobHost() {
        return this.flags.blobHost;
    }
    blobPort() {
        return this.flags.blobPort;
    }
    async location() {
        const location = this.flags.location || process.cwd();
        await accessAsync(location);
        return location;
    }
    silent() {
        if (this.flags.silent !== undefined) {
            return true;
        }
        return false;
    }
    async debug() {
        if (typeof this.flags.debug === "string") {
            // Enable debug log to file
            const debugFilePath = this.flags.debug;
            await accessAsync(path_1.dirname(debugFilePath));
            return debugFilePath;
        }
        if (this.flags.debug === true) {
            throw RangeError(`Must provide a debug log file path for parameter -d or --debug`);
        }
        // By default disable debug log
    }
}
exports.default = BlobEnvironment;
//# sourceMappingURL=BlobEnvironment.js.map