"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = require("path");
const constants_1 = require("../common/utils/constants");
const BlobConfiguration_1 = tslib_1.__importDefault(require("./BlobConfiguration"));
const BlobEnvironment_1 = tslib_1.__importDefault(require("./BlobEnvironment"));
const BlobServer_1 = tslib_1.__importDefault(require("./BlobServer"));
const SqlBlobConfiguration_1 = tslib_1.__importDefault(require("./SqlBlobConfiguration"));
const SqlBlobServer_1 = tslib_1.__importDefault(require("./SqlBlobServer"));
const constants_2 = require("./utils/constants");
class BlobServerFactory {
    async createServer() {
        // TODO: Check it's in Visual Studio Code environment or not
        const isVSC = false;
        if (!isVSC) {
            const env = new BlobEnvironment_1.default();
            const location = await env.location();
            const debugFilePath = await env.debug();
            // TODO: Check we need to create blob server against SQL or Loki
            const databaseConnectionString = process.env.AZURITE_DB;
            const isSQL = databaseConnectionString !== undefined;
            if (isSQL) {
                const config = new SqlBlobConfiguration_1.default(env.blobHost(), env.blobPort(), databaseConnectionString, constants_1.DEFAULT_SQL_OPTIONS, constants_2.DEFAULT_BLOB_PERSISTENCE_ARRAY, !env.silent(), undefined, debugFilePath !== undefined, debugFilePath);
                return new SqlBlobServer_1.default(config);
            }
            else {
                const config = new BlobConfiguration_1.default(env.blobHost(), env.blobPort(), path_1.join(location, constants_2.DEFAULT_BLOB_LOKI_DB_PATH), path_1.join(location, constants_2.DEFAULT_BLOB_EXTENT_LOKI_DB_PATH), constants_2.DEFAULT_BLOB_PERSISTENCE_ARRAY, !env.silent(), undefined, debugFilePath !== undefined, debugFilePath);
                return new BlobServer_1.default(config);
            }
        }
        else {
            // TODO: Add BlobServer construction in VSC
            // Visual Studio Code Loki
            // Visual Studio Code SQL
            throw new Error("Not implemented.");
        }
    }
}
exports.BlobServerFactory = BlobServerFactory;
//# sourceMappingURL=BlobServerFactory.js.map