"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = require("path");
const BlobConfiguration_1 = tslib_1.__importDefault(require("../blob/BlobConfiguration"));
const BlobServer_1 = tslib_1.__importDefault(require("../blob/BlobServer"));
const constants_1 = require("../blob/utils/constants");
const Logger = tslib_1.__importStar(require("./Logger"));
const NoLoggerStrategy_1 = tslib_1.__importDefault(require("./NoLoggerStrategy"));
const utils_1 = require("./utils/utils");
const VSCChannelLoggerStrategy_1 = tslib_1.__importDefault(require("./VSCChannelLoggerStrategy"));
const VSCChannelWriteStream_1 = tslib_1.__importDefault(require("./VSCChannelWriteStream"));
const VSCEnvironment_1 = tslib_1.__importDefault(require("./VSCEnvironment"));
const VSCServerManagerBase_1 = tslib_1.__importDefault(require("./VSCServerManagerBase"));
const VSCServerManagerClosedState_1 = tslib_1.__importDefault(require("./VSCServerManagerClosedState"));
class VSCServerManagerBlob extends VSCServerManagerBase_1.default {
    constructor() {
        super("Azurite Blob Service", new VSCServerManagerClosedState_1.default());
        this.accessChannelStream = new VSCChannelWriteStream_1.default("Azurite Blob");
        this.debuggerLoggerStrategy = new VSCChannelLoggerStrategy_1.default("Azurite Blob Debug");
    }
    getStartCommand() {
        return "azurite.start_blob";
    }
    getCloseCommand() {
        return "azurite.close_blob";
    }
    getCleanCommand() {
        return "azurite.clean_blob";
    }
    async createImpl() {
        const config = await this.getConfiguration();
        Logger.default.strategy = config.enableDebugLog
            ? this.debuggerLoggerStrategy
            : new NoLoggerStrategy_1.default();
        this.server = new BlobServer_1.default(config);
    }
    async startImpl() {
        await this.server.start();
    }
    async closeImpl() {
        this.server.close();
    }
    async cleanImpl() {
        const config = await this.getConfiguration();
        await utils_1.rimrafAsync(config.extentDBPath);
        await utils_1.rimrafAsync(config.metadataDBPath);
        for (const path of config.persistencePathArray) {
            await utils_1.rimrafAsync(path.persistencyPath);
        }
    }
    async getConfiguration() {
        const env = new VSCEnvironment_1.default();
        const location = await env.location();
        // Initialize server configuration
        const config = new BlobConfiguration_1.default(env.blobHost(), env.blobPort(), path_1.join(location, constants_1.DEFAULT_BLOB_LOKI_DB_PATH), path_1.join(location, constants_1.DEFAULT_BLOB_EXTENT_LOKI_DB_PATH), constants_1.DEFAULT_BLOB_PERSISTENCE_ARRAY, !env.silent(), this.accessChannelStream, env.debug() === true, undefined);
        return config;
    }
}
exports.default = VSCServerManagerBlob;
//# sourceMappingURL=VSCServerManagerBlob.js.map