"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = require("fs");
const path_1 = require("path");
const util_1 = require("util");
const QueueConfiguration_1 = tslib_1.__importDefault(require("../queue/QueueConfiguration"));
const QueueServer_1 = tslib_1.__importDefault(require("../queue/QueueServer"));
const constants_1 = require("../queue/utils/constants");
const Logger = tslib_1.__importStar(require("./Logger"));
const NoLoggerStrategy_1 = tslib_1.__importDefault(require("./NoLoggerStrategy"));
const VSCChannelLoggerStrategy_1 = tslib_1.__importDefault(require("./VSCChannelLoggerStrategy"));
const VSCChannelWriteStream_1 = tslib_1.__importDefault(require("./VSCChannelWriteStream"));
const VSCQueueEnvironment_1 = tslib_1.__importDefault(require("./VSCQueueEnvironment"));
const VSCServerManagerBase_1 = tslib_1.__importDefault(require("./VSCServerManagerBase"));
const VSCServerManagerClosedState_1 = tslib_1.__importDefault(require("./VSCServerManagerClosedState"));
const rimraf = require("rimraf");
const accessAsync = util_1.promisify(fs_1.access);
const rimrafAsync = util_1.promisify(rimraf);
class VSCServerManagerBlob extends VSCServerManagerBase_1.default {
    constructor() {
        super("Azurite Queue Service", new VSCServerManagerClosedState_1.default());
        this.accessChannelStream = new VSCChannelWriteStream_1.default("Azurite Queue");
        this.debuggerLoggerStrategy = new VSCChannelLoggerStrategy_1.default("Azurite Queue Debug");
    }
    getStartCommand() {
        return "azurite.start_queue";
    }
    getCloseCommand() {
        return "azurite.close_queue";
    }
    getCleanCommand() {
        return "azurite.clean_queue";
    }
    async createImpl() {
        const config = await this.getConfiguration();
        Logger.default.strategy = config.enableDebugLog
            ? this.debuggerLoggerStrategy
            : new NoLoggerStrategy_1.default();
        this.server = new QueueServer_1.default(config);
    }
    async startImpl() {
        await this.server.start();
    }
    async closeImpl() {
        this.server.close();
    }
    async cleanImpl() {
        const config = await this.getConfiguration();
        await rimrafAsync(config.extentDBPath);
        await rimrafAsync(config.metadataDBPath);
        for (const path of config.persistencePathArray) {
            await rimrafAsync(path.persistencyPath);
        }
    }
    async getConfiguration() {
        const env = new VSCQueueEnvironment_1.default();
        const location = await env.location();
        await accessAsync(location);
        const DEFUALT_QUEUE_PERSISTENCE_ARRAY = [
            {
                persistencyId: "Default",
                persistencyPath: path_1.join(location, constants_1.DEFAULT_QUEUE_PERSISTENCE_PATH),
                maxConcurrency: 10
            }
        ];
        // Initialize server configuration
        const config = new QueueConfiguration_1.default(env.queueHost(), env.queuePort(), path_1.join(location, constants_1.DEFAULT_QUEUE_LOKI_DB_PATH), path_1.join(location, constants_1.DEFAULT_QUEUE_EXTENT_LOKI_DB_PATH), DEFUALT_QUEUE_PERSISTENCE_ARRAY, !env.silent(), this.accessChannelStream, env.debug() === true, undefined);
        return config;
    }
}
exports.default = VSCServerManagerBlob;
//# sourceMappingURL=VSCServerManagerQueue.js.map